using System;
using System.Collections.Generic;
using System.Linq;
using EdFi.Ods.Sdk;
using EdFi.Ods.Sdk.Models.WiDpi_Profile_Public;
using RestSharp;
  
namespace EdFi.Ods.Sdk.Apis.WiDpi_Profile_Public 
{
    public class StudentSchoolAssociationWisconsinExtsApi 
    {
        private readonly IRestClient client;

        public StudentSchoolAssociationWisconsinExtsApi(IRestClient client)
        {
            this.client = client;
        }
      
        /// <summary>
        /// Retrieves resources based with paging capabilities (using the &quot;Get All&quot; pattern). This GET operation provides access to resources using the &quot;Get All&quot; pattern. In this version of the API there is support for paging.
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<StudentSchoolAssociationWisconsinExt_Readable>> GetStudentSchoolAssociationWisconsinExtsAll(int? offset= null, int? limit= null) 
        {
            var request = new RestRequest("/studentSchoolAssociationWisconsinExts", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            request.AddHeader("Accept", "application/vnd.ed-fi.studentschoolassociationwisconsinext.widpi-profile-public.readable+json");
            var response = client.Execute<List<StudentSchoolAssociationWisconsinExt_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves resources matching values of an example resource (using the &quot;Get By Example&quot; pattern). This GET operation provides access to resources using the &quot;Get by Example&quot; search pattern.  The values of any properties of the resource that are specified will be used to return all matching results (if it exists).
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <param name="schoolId">School enrolling the Student.</param>
        /// <param name="studentUniqueId">A unique alpha-numeric code assigned to a student.</param>
        /// <param name="entryDate">The entry date associated with the student's enrollment.</param>
        /// <param name="id"></param>
        /// <param name="completedSchoolTerm">Indicates whether or not a student completed the school term during the school enrollment period.  It is collected for every student enrollment record and is not related to graduation.  A student could have more than one enrollment record for a school year.</param>
        /// <param name="expectedTransferEducationOrganizationId">The student's expected transfer agency (EducationOrganizationId)</param>
        /// <param name="expectedTransferSchoolId">The student's expected transfer school (SchoolId)</param>
        /// <param name="actualDaysAttendance">Aggregate value that captures the actual days in attendance for a student.</param>
        /// <param name="possibleDaysAttendance">Aggregate value that capture the possible days in attendance for a student</param>
        /// <param name="privateSchoolChoiceProgramParticipant">Indicates whether a student is a choice student or not</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<StudentSchoolAssociationWisconsinExt_Readable>> GetStudentSchoolAssociationWisconsinExtsAll(int? offset= null, int? limit= null, int? schoolId= null, string studentUniqueId= null, DateTime? entryDate= null, string id= null, bool? completedSchoolTerm= null, int? expectedTransferEducationOrganizationId= null, int? expectedTransferSchoolId= null, double? actualDaysAttendance= null, double? possibleDaysAttendance= null, bool? privateSchoolChoiceProgramParticipant= null) 
        {
            var request = new RestRequest("/studentSchoolAssociationWisconsinExts", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            if (schoolId != null)
                request.AddParameter("schoolId", schoolId);
            if (studentUniqueId != null)
                request.AddParameter("studentUniqueId", studentUniqueId);
            if (entryDate != null)
                request.AddParameter("entryDate", entryDate);
            if (id != null)
                request.AddParameter("id", id);
            if (completedSchoolTerm != null)
                request.AddParameter("completedSchoolTerm", completedSchoolTerm);
            if (expectedTransferEducationOrganizationId != null)
                request.AddParameter("expectedTransferEducationOrganizationId", expectedTransferEducationOrganizationId);
            if (expectedTransferSchoolId != null)
                request.AddParameter("expectedTransferSchoolId", expectedTransferSchoolId);
            if (actualDaysAttendance != null)
                request.AddParameter("actualDaysAttendance", actualDaysAttendance);
            if (possibleDaysAttendance != null)
                request.AddParameter("possibleDaysAttendance", possibleDaysAttendance);
            if (privateSchoolChoiceProgramParticipant != null)
                request.AddParameter("privateSchoolChoiceProgramParticipant", privateSchoolChoiceProgramParticipant);
            request.AddHeader("Accept", "application/vnd.ed-fi.studentschoolassociationwisconsinext.widpi-profile-public.readable+json");
            var response = client.Execute<List<StudentSchoolAssociationWisconsinExt_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the values of the resource's natural key (using the &quot;Get By Key&quot; pattern). This GET operation provides access to resources using the &quot;Get by Key&quot; search pattern. The values of the natural key of the resource must be fully specified, and the service will return the matching result (if it exists).
        /// </summary>
        /// <param name="schoolId">School enrolling the Student.</param>
        /// <param name="studentUniqueId">A unique alpha-numeric code assigned to a student.</param>
        /// <param name="entryDate">The entry date associated with the student's enrollment.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<StudentSchoolAssociationWisconsinExt_Readable> GetStudentSchoolAssociationWisconsinExtByKey(int? schoolId, string studentUniqueId, DateTime? entryDate, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/studentSchoolAssociationWisconsinExts", Method.GET);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (schoolId == null || studentUniqueId == null || entryDate == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            if (schoolId != null)
                request.AddParameter("schoolId", schoolId);
            if (studentUniqueId != null)
                request.AddParameter("studentUniqueId", studentUniqueId);
            if (entryDate != null)
                request.AddParameter("entryDate", entryDate);
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.studentschoolassociationwisconsinext.widpi-profile-public.readable+json");
            var response = client.Execute<StudentSchoolAssociationWisconsinExt_Readable>(request);

            return response;
        }
        /// <summary>
        /// Creates or updates resources based on the natural key values of the supplied resource. The POST operation can be used to create or update resources. In database terms, this is often referred to as an &quot;upsert&quot; operation (insert + update).  Clients should NOT include the resource &quot;id&quot; in the JSON body because it will result in an error (you must use a PUT operation to update a resource by &quot;id&quot;). The web service will identify whether the resource already exists based on the natural key values provided, and update or create the resource appropriately.
        /// </summary>
        /// <param name="body">The JSON representation of the &quot;studentSchoolAssociationWisconsinExt&quot; resource to be created or updated.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse PostStudentSchoolAssociationWisconsinExts(StudentSchoolAssociationWisconsinExt_Writable body) 
        {
            var request = new RestRequest("/studentSchoolAssociationWisconsinExts", Method.POST);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (body == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddBody(body);
            request.Parameters.First(param => param.Type == ParameterType.RequestBody).Name = "application/vnd.ed-fi.studentschoolassociationwisconsinext.widpi-profile-public.writable+json";
            var response = client.Execute(request);

            var location = response.Headers.FirstOrDefault(x => x.Name == "Location");

            if (location != null && !string.IsNullOrWhiteSpace(location.Value.ToString()))
                body.id = location.Value.ToString().Split('/').Last();
            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the resource's identifier (using the &quot;Get By Id&quot; pattern). This GET operation retrieves a resource by the specified resource identifier.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be retrieved.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<StudentSchoolAssociationWisconsinExt_Readable> GetStudentSchoolAssociationWisconsinExtsById(string id, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/studentSchoolAssociationWisconsinExts/{id}", Method.GET);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.studentschoolassociationwisconsinext.widpi-profile-public.readable+json");
            var response = client.Execute<StudentSchoolAssociationWisconsinExt_Readable>(request);

            return response;
        }
        /// <summary>
        /// Updates or creates a resource based on the resource identifier. The PUT operation is used to update or create a resource by identifier.  If the resource doesn't exist, the resource will be created using that identifier.  Additionally, natural key values cannot be changed using this operation, and will not be modified in the database.  If the resource &quot;id&quot; is provided in the JSON body, it will be ignored as well.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be updated.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the PUT from updating a resource modified by another consumer.</param>
        /// <param name="body">The JSON representation of the &quot;studentSchoolAssociationWisconsinExt&quot; resource to be updated.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse PutStudentSchoolAssociationWisconsinExt(string id, string IfMatch, StudentSchoolAssociationWisconsinExt_Writable body) 
        {
            var request = new RestRequest("/studentSchoolAssociationWisconsinExts/{id}", Method.PUT);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null || body == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            request.AddBody(body);
            request.Parameters.First(param => param.Type == ParameterType.RequestBody).Name = "application/vnd.ed-fi.studentschoolassociationwisconsinext.widpi-profile-public.writable+json";
            var response = client.Execute(request);

            var location = response.Headers.FirstOrDefault(x => x.Name == "Location");

            if (location != null && !string.IsNullOrWhiteSpace(location.Value.ToString()))
                body.id = location.Value.ToString().Split('/').Last();
            return response;
        }
        /// <summary>
        /// Deletes an existing resource using the resource identifier. The DELETE operation is used to delete an existing resource by identifier.  If the resource doesn't exist, an error will result (the resource will not be found).
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be deleted.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the DELETE from removing a resource modified by another consumer.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse DeleteStudentSchoolAssociationWisconsinExtById(string id, string IfMatch= null) 
        {
            var request = new RestRequest("/studentSchoolAssociationWisconsinExts/{id}", Method.DELETE);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            var response = client.Execute(request);

            return response;
        }
        }
    }

