using System;
using System.Collections.Generic;
using System.Linq;
using EdFi.Ods.Sdk;
using EdFi.Ods.Sdk.Models.WiDpi_Profile_Public_Only_SPED;
using RestSharp;
  
namespace EdFi.Ods.Sdk.Apis.WiDpi_Profile_Public_Only_SPED 
{
    public class GradingPeriodsApi 
    {
        private readonly IRestClient client;

        public GradingPeriodsApi(IRestClient client)
        {
            this.client = client;
        }
      
        /// <summary>
        /// Retrieves resources based with paging capabilities (using the &quot;Get All&quot; pattern). This GET operation provides access to resources using the &quot;Get All&quot; pattern. In this version of the API there is support for paging.
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<GradingPeriod_Readable>> GetGradingPeriodsAll(int? offset= null, int? limit= null) 
        {
            var request = new RestRequest("/gradingPeriods", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            request.AddHeader("Accept", "application/vnd.ed-fi.gradingperiod.widpi-profile-public-only-sped.readable+json");
            var response = client.Execute<List<GradingPeriod_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves resources matching values of an example resource (using the &quot;Get By Example&quot; pattern). This GET operation provides access to resources using the &quot;Get by Example&quot; search pattern.  The values of any properties of the resource that are specified will be used to return all matching results (if it exists).
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <param name="descriptor">The name of the grading period during the school year in which the grade is offered (e.g., 1st cycle, 1st semester)</param>
        /// <param name="schoolId">School Identity Column</param>
        /// <param name="beginDate">Month, day, and year of the first day of the GradingPeriod.</param>
        /// <param name="totalInstructionalDays">Total days available for educational instruction during the grading period.</param>
        /// <param name="endDate">Month, day, and year of the last day of the GradingPeriod.</param>
        /// <param name="periodSequence">The sequential order of this period relative to other periods.</param>
        /// <param name="id"></param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<GradingPeriod_Readable>> GetGradingPeriodsAll(int? offset= null, int? limit= null, string descriptor= null, int? schoolId= null, DateTime? beginDate= null, int? totalInstructionalDays= null, DateTime? endDate= null, int? periodSequence= null, string id= null) 
        {
            var request = new RestRequest("/gradingPeriods", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            if (descriptor != null)
                request.AddParameter("descriptor", descriptor);
            if (schoolId != null)
                request.AddParameter("schoolId", schoolId);
            if (beginDate != null)
                request.AddParameter("beginDate", beginDate);
            if (totalInstructionalDays != null)
                request.AddParameter("totalInstructionalDays", totalInstructionalDays);
            if (endDate != null)
                request.AddParameter("endDate", endDate);
            if (periodSequence != null)
                request.AddParameter("periodSequence", periodSequence);
            if (id != null)
                request.AddParameter("id", id);
            request.AddHeader("Accept", "application/vnd.ed-fi.gradingperiod.widpi-profile-public-only-sped.readable+json");
            var response = client.Execute<List<GradingPeriod_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the values of the resource's natural key (using the &quot;Get By Key&quot; pattern). This GET operation provides access to resources using the &quot;Get by Key&quot; search pattern. The values of the natural key of the resource must be fully specified, and the service will return the matching result (if it exists).
        /// </summary>
        /// <param name="descriptor">The name of the grading period during the school year in which the grade is offered (e.g., 1st cycle, 1st semester)</param>
        /// <param name="schoolId">School Identity Column</param>
        /// <param name="beginDate">Month, day, and year of the first day of the GradingPeriod.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<GradingPeriod_Readable> GetGradingPeriodByKey(string descriptor, int? schoolId, DateTime? beginDate, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/gradingPeriods", Method.GET);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (descriptor == null || schoolId == null || beginDate == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            if (descriptor != null)
                request.AddParameter("descriptor", descriptor);
            if (schoolId != null)
                request.AddParameter("schoolId", schoolId);
            if (beginDate != null)
                request.AddParameter("beginDate", beginDate);
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.gradingperiod.widpi-profile-public-only-sped.readable+json");
            var response = client.Execute<GradingPeriod_Readable>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the resource's identifier (using the &quot;Get By Id&quot; pattern). This GET operation retrieves a resource by the specified resource identifier.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be retrieved.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<GradingPeriod_Readable> GetGradingPeriodsById(string id, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/gradingPeriods/{id}", Method.GET);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.gradingperiod.widpi-profile-public-only-sped.readable+json");
            var response = client.Execute<GradingPeriod_Readable>(request);

            return response;
        }
        /// <summary>
        /// Deletes an existing resource using the resource identifier. The DELETE operation is used to delete an existing resource by identifier.  If the resource doesn't exist, an error will result (the resource will not be found).
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be deleted.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the DELETE from removing a resource modified by another consumer.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse DeleteGradingPeriodById(string id, string IfMatch= null) 
        {
            var request = new RestRequest("/gradingPeriods/{id}", Method.DELETE);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            var response = client.Execute(request);

            return response;
        }
        }
    }

