using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace EdFi.Ods.Sdk.Models.WiDpi_Profile_Public 
{
    public class Course_Readable 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// A reference to the related EducationOrganization resource.
        /// </summary>
        public EducationOrganizationReference educationOrganizationReference { get; set; }

        /// <summary>
        /// TThe actual code that identifies the organization of subject matter and related learning experiences provided for the instruction of students.
        /// </summary>
        public string code { get; set; }

        /// <summary>
        /// The descriptive name given to a course of study offered in a school or other institution or organization. In departmentalized classes at the elementary, secondary, and postsecondary levels (and for staff development activities), this refers to the name by which a course is identified (e.g., American History, English III). For elementary and other non-departmentalized classes, it refers to any portion of the instruction for which a grade or report is assigned (e.g., reading, composition, spelling, and language arts).
        /// </summary>
        public string title { get; set; }

        /// <summary>
        /// The number of parts identified for a course.
        /// </summary>
        public int? numberOfParts { get; set; }

        /// <summary>
        /// The intended major subject area of the course.  NEDM: Secondary Course Subject Area
        /// </summary>
        public string academicSubjectDescriptor { get; set; }

        /// <summary>
        /// A description of the content standards and goals covered in the course. Reference may be made to state or national content standards.  NEDM: Course Description
        /// </summary>
        public string description { get; set; }

        /// <summary>
        /// An unordered collection of courseIdentificationCodes.  A standard code that identifies the organization of subject matter and related learning experiences provided for the instruction of students.
        /// </summary>
        public List<CourseIdentificationCode_Readable> identificationCodes { get; set; }

        /// <summary>
        /// An unordered collection of courseLevelCharacteristics.  Indication of the nature and difficulty of instruction: Remedial, Basic, Honors, AP, IB, Dual Credit, CTE, etc.
        /// </summary>
        public List<CourseLevelCharacteristic_Readable> levelCharacteristics { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

