using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace EdFi.Ods.Sdk.Models.WiDpi_Profile_Public 
{
    public class DisciplineAction_Readable 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// A reference to the related Student resource.
        /// </summary>
        public StudentReference studentReference { get; set; }

        /// <summary>
        /// Identifier assigned by the education organization to the discipline action.
        /// </summary>
        public string identifier { get; set; }

        /// <summary>
        /// The date of the DisciplineAction.
        /// </summary>
        public DateTime? disciplineDate { get; set; }

        /// <summary>
        /// The length of time in school days for the Discipline Action (e.g. removal, detention), if applicable.
        /// </summary>
        public double? length { get; set; }

        /// <summary>
        /// Indicates the actual length in school days of a student's disciplinary assignment.
        /// </summary>
        public double? actualDisciplineActionLength { get; set; }

        /// <summary>
        /// Identifies if the duration of the expulsion has been modified from the federally required one year of expulsion for a fire arms incident.
        /// </summary>
        public string modifiedTermType { get; set; }

        /// <summary>
        /// Following an expulsion, the student had early reinstatement condition to return to school prior to the end of the expulsion.
        /// </summary>
        public bool? earlyReinstatementCondition { get; set; }

        /// <summary>
        /// An unordered collection of disciplineActionDisciplines.  Type of action, such as removal from the classroom, used to discipline the student involved as a perpetrator in a discipline incident.
        /// </summary>
        public List<DisciplineActionDiscipline_Readable> disciplines { get; set; }

        /// <summary>
        /// An unordered collection of disciplineActionDisciplineIncidents.  
        /// </summary>
        public List<DisciplineActionDisciplineIncident_Readable> disciplineIncidents { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

